==> estateplat-common-1.2.3-20181108.110720-210-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjLqxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * 林权信息实体类
 * Created by lst on 2015/3/12.
 */
public class DjsjLqxx {
    private String djh;
    private String gyqk;
    private String qy;
    private String bdcdyh;
    private String xdm;
    private String zl;
    private String lb;
    private String xb;
    private Double mj;
    private Integer zs;
    private String lz;
    private String zysz;
    private Integer zlnd;
    private Date gxrq;
    private String bz;
    private String lqDcbIndex;
    private String fj;
    private String dcry;
    private Date dcrq;
    private Date jlrq;
    private String zddcbIndex;
    private String mjdw;

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLqDcbIndex() {
        return lqDcbIndex;
    }

    public void setLqDcbIndex(String lqDcbIndex) {
        this.lqDcbIndex = lqDcbIndex;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDcry() {
        return dcry;
    }

    public void setDcry(String dcry) {
        this.dcry = dcry;
    }

    public Date getDcrq() {
        return dcrq;
    }

    public void setDcrq(Date dcrq) {
        this.dcrq = dcrq;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }
}

==> estateplat-common-1.2.4-20211203.090126-946-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjLqxx.java <==
package cn.gtmap.estateplat.model.server.core;

import java.util.Date;

/**
 * 林权信息实体类
 * Created by lst on 2015/3/12.
 */
public class DjsjLqxx {
    private String djh;
    private String gyqk;
    private String qy;
    private String bdcdyh;
    private String xdm;
    private String zl;
    private String lb;
    private String xb;
    private Double mj;
    private Integer zs;
    private String lz;
    private String zysz;
    private Integer zlnd;
    private Date gxrq;
    private String bz;
    private String lqDcbIndex;
    private String fj;
    private String dcry;
    private Date dcrq;
    private Date jlrq;
    private String zddcbIndex;
    private String mjdw;
    private String sllb;

    public String getSllb() {
        return sllb;
    }

    public void setSllb(String sllb) {
        this.sllb = sllb;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getQy() {
        return qy;
    }

    public void setQy(String qy) {
        this.qy = qy;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getXdm() {
        return xdm;
    }

    public void setXdm(String xdm) {
        this.xdm = xdm;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getLb() {
        return lb;
    }

    public void setLb(String lb) {
        this.lb = lb;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Double getMj() {
        return mj;
    }

    public void setMj(Double mj) {
        this.mj = mj;
    }

    public Integer getZs() {
        return zs;
    }

    public void setZs(Integer zs) {
        this.zs = zs;
    }

    public String getLz() {
        return lz;
    }

    public void setLz(String lz) {
        this.lz = lz;
    }

    public String getZysz() {
        return zysz;
    }

    public void setZysz(String zysz) {
        this.zysz = zysz;
    }

    public Integer getZlnd() {
        return zlnd;
    }

    public void setZlnd(Integer zlnd) {
        this.zlnd = zlnd;
    }

    public Date getGxrq() {
        return gxrq;
    }

    public void setGxrq(Date gxrq) {
        this.gxrq = gxrq;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLqDcbIndex() {
        return lqDcbIndex;
    }

    public void setLqDcbIndex(String lqDcbIndex) {
        this.lqDcbIndex = lqDcbIndex;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getDcry() {
        return dcry;
    }

    public void setDcry(String dcry) {
        this.dcry = dcry;
    }

    public Date getDcrq() {
        return dcrq;
    }

    public void setDcrq(Date dcrq) {
        this.dcrq = dcrq;
    }

    public Date getJlrq() {
        return jlrq;
    }

    public void setJlrq(Date jlrq) {
        this.jlrq = jlrq;
    }

    public String getZddcbIndex() {
        return zddcbIndex;
    }

    public void setZddcbIndex(String zddcbIndex) {
        this.zddcbIndex = zddcbIndex;
    }

    public String getMjdw() {
        return mjdw;
    }

    public void setMjdw(String mjdw) {
        this.mjdw = mjdw;
    }
}
